@@ -198,7 +198,8 @@ plot.shapleyPermEx <- function(x, ylim = c(0, 1), ...) {
   }
 }
 
-ggplot.shapleyPermEx <- function(x, ylim = c(0, 1), title = NULL, ...) {
+ggplot.shapleyPermEx <- function(data, mapping = aes(), ylim = c(0, 1), title = NULL, ..., environment = parent.frame()) {
+  x <- data
   if (!is.null(x$y)) {
     pch = c(21, 24, 25)
     nodeggplot(list(x$Shapley,x$SobolS,x$SobolT), xname=c("Shapley effect","Full first Sobol'", "Independent total Sobol'"), ylim = ylim, title = title, pch = pch)
