@@ -320,8 +320,9 @@ plot.sobolmartinez <- function(x, ylim = c(0, 1),
   }
 }
 
-ggplot.sobolmartinez <- function(x, ylim = c(0, 1), 
-                               y_col = NULL, y_dim3 = NULL, ...) {
+ggplot.sobolmartinez <- function(data, mapping = aes(), ylim = c(0, 1), 
+                               y_col = NULL, y_dim3 = NULL, ..., environment = parent.frame()) {
+  x <- data
   if (!is.null(x$y)) {
     p <- ncol(x$X1)
     pch = c(21, 24)
